@@ -38,8 +38,6 @@ def barplot(
     highlight=None,
     ax=None,
     legend_kwargs=None,
-    savefig=False,
-    savefig_kwargs=None,
 ):
     """
     Creates an overlaid scatter and barplot for a set of values (either gene
@@ -82,8 +80,6 @@ def barplot(
     if ax is None:
         figsize = (len(values) / 15 + 0.5, 2)
         fig, ax = plt.subplots(figsize=figsize)
-    else:
-        fig = ax.figure
 
     # Get ymin and max
     ymin = values.min()
@@ -194,7 +190,7 @@ def barplot(
             ax.legend(**kwargs)
 
     else:
-        logging.warning('Missing "project" and "condition" columns in sample ' "table.")
+        logging.warning("Missing `project` and `condition` columns in `sample_table.`")
         ax.bar(range(len(values)), values, width=1, align="edge")
         nbars = len(values)
 
@@ -211,22 +207,11 @@ def barplot(
     # X-axis
     ax.hlines(0, xmin, xmax, color="k")
 
-    # Save figure
-    if savefig:
-        _save_figures(fig, savefig_kwargs)
-
     return ax
 
 
 def plot_expression(
-    ica_data,
-    gene,
-    projects=None,
-    highlight=None,
-    ax=None,
-    legend_kwargs=None,
-    savefig=False,
-    savefig_kwargs=None,
+    ica_data, gene, projects=None, highlight=None, ax=None, legend_kwargs=None
 ):
     """
     Creates a barplot showing an gene's expression across the compendium
@@ -262,27 +247,18 @@ def plot_expression(
         label = "${}$ Expression".format(gene)
 
     return barplot(
-        values,
-        ica_data.sample_table,
-        label,
-        projects,
-        highlight,
-        ax,
-        legend_kwargs,
-        savefig=savefig,
-        savefig_kwargs=savefig_kwargs,
+        values=values,
+        sample_table=ica_data.sample_table,
+        ylabel=label,
+        projects=projects,
+        highlight=highlight,
+        ax=ax,
+        legend_kwargs=legend_kwargs,
     )
 
 
 def plot_activities(
-    ica_data,
-    imodulon,
-    projects=None,
-    highlight=None,
-    ax=None,
-    legend_kwargs=None,
-    savefig=False,
-    savefig_kwargs=None,
+    ica_data, imodulon, projects=None, highlight=None, ax=None, legend_kwargs=None
 ):
     """
     Creates a barplot showing an iModulon's activity across the compendium
@@ -317,27 +293,18 @@ def plot_activities(
     label = "{} iModulon\nActivity".format(imodulon)
 
     return barplot(
-        values,
-        ica_data.sample_table,
-        label,
-        projects,
-        highlight,
-        ax,
-        legend_kwargs,
-        savefig=savefig,
-        savefig_kwargs=savefig_kwargs,
+        values=values,
+        sample_table=ica_data.sample_table,
+        ylabel=label,
+        projects=projects,
+        highlight=highlight,
+        ax=ax,
+        legend_kwargs=legend_kwargs,
     )
 
 
 def plot_metadata(
-    ica_data,
-    column,
-    projects=None,
-    highlight=None,
-    ax=None,
-    legend_kwargs=None,
-    savefig=False,
-    savefig_kwargs=None,
+    ica_data, column, projects=None, highlight=None, ax=None, legend_kwargs=None
 ):
     """
     Creates a barplot for values in the sample table
@@ -377,15 +344,13 @@ def plot_metadata(
         raise ValueError("Column not in sample table: {}".format(column))
 
     return barplot(
-        values,
-        table,
-        column,
-        projects,
-        highlight,
-        ax,
-        legend_kwargs,
-        savefig=savefig,
-        savefig_kwargs=savefig_kwargs,
+        values=values,
+        sample_table=table,
+        ylabel=column,
+        projects=projects,
+        highlight=highlight,
+        ax=ax,
+        legend_kwargs=legend_kwargs,
     )
 
 
@@ -401,8 +366,6 @@ def plot_regulon_histogram(
     alpha=0.7,
     ax_font_kwargs=None,
     legend_kwargs=None,
-    savefig=False,
-    savefig_kwargs=None,
 ):
     """
     Plots a histogram of regulon vs non-regulon genes by iModulon weighting.
@@ -453,8 +416,6 @@ def plot_regulon_histogram(
     # If ax is None, create ax on which to generate histogram
     if ax is None:
         fig, ax = plt.subplots()
-    else:
-        fig = ax.figure
 
     # If bins is None, generate optimal number of bins
     if bins is None:
@@ -483,10 +444,10 @@ def plot_regulon_histogram(
         df_top_enrich = df_enriched.sort_values(
             ["imodulon", "qvalue", "n_regs"]
         ).drop_duplicates("imodulon")
-        reg = df_top_enrich.set_index("imodulon").loc[imodulon, "regulator"]
-        if not isinstance(reg, str):
-            if pd.isna(reg):
-                reg = None
+        try:
+            reg = df_top_enrich.set_index("imodulon").loc[imodulon, "regulator"]
+        except KeyError:
+            reg = None
 
     # Use regulator value to find regulon genes
     if reg is not None:
@@ -548,10 +509,6 @@ def plot_regulon_histogram(
     # Add legend
     ax.legend(**legend_kwargs)
 
-    # Save figure
-    if savefig:
-        _save_figures(fig, savefig_kwargs)
-
     return ax
 
 
@@ -579,8 +536,6 @@ def scatterplot(
     scatter_kwargs=None,
     label_font_kwargs=None,
     legend_kwargs=None,
-    savefig=False,
-    savefig_kwargs=None,
 ):
     """
     Generates a scatter-plot of the data given, with options for coloring by
@@ -636,8 +591,6 @@ def scatterplot(
 
     if ax is None:
         fig, ax = plt.subplots()
-    else:
-        fig = ax.figure
 
     if show_labels == "auto":
         show_labels = len(x) <= 20
@@ -795,10 +748,6 @@ def scatterplot(
     if legend or fit_line:
         ax.legend(**legend_kwargs)
 
-    # Save figure
-    if savefig:
-        _save_figures(fig, savefig_kwargs)
-
     return ax
 
 
@@ -818,7 +767,7 @@ def plot_gene_weights(ica_data, imodulon, by="start", xaxis=None, xname="", **kw
         Values on custom x-axis
     xname: str, optional
         Name of x-axis if using custom x-axis
-    **kwargs: dict, optional
+    **kwargs:
         Additional keyword arguments passed to :func:`pymodulon.plotting.scatterplot`
     Returns
     -------
@@ -1003,7 +952,7 @@ def compare_gene_weights(
     use_org1_names: bool
         If true, use gene names from first organism. If false, use gene names
         from second organism (default: True)
-    **kwargs: dict, optional
+    **kwargs:
         Additional keyword arguments passed to :func:`pymodulon.plotting.scatterplot`
 
     Returns
@@ -1182,7 +1131,7 @@ def compare_expression(ica_data, gene1, gene2, **kwargs):
         Gene to plot on the x-axis
     gene2: str
         Gene to plot on the y-axis
-    **kwargs: dict, optional
+    **kwargs:
         Additional keyword arguments passed to :func:`pymodulon.plotting.scatterplot`
 
     Returns
@@ -1232,7 +1181,7 @@ def compare_activities(ica_data, imodulon1, imodulon2, **kwargs):
         Name of the iModulon to plot on the x-axis
     imodulon2: int or str
         Name of the iModulon to plot on the y-axis
-    **kwargs: dict, optional
+    **kwargs:
         Additional keyword arguments passed to :func:`pymodulon.plotting.scatterplot`
 
     Returns
@@ -1290,7 +1239,7 @@ def plot_dima(
         Automatically adjust labels (default: True)
     table: bool
         Return differential iModulon activity table (default: False)
-    **kwargs: dict, optional
+    **kwargs:
         Additional keyword arguments passed to :func:`pymodulon.plotting.scatterplot`
 
     Returns
@@ -1392,7 +1341,7 @@ def plot_dima(
 # Other plots #
 ###############
 
-
+# TODO: Add kind=bar to plot top explained variance
 def plot_explained_variance(ica_data, pc=True, ax=None):
     """
     Plots the cumulative explained variance for independent components and,
@@ -1413,15 +1362,15 @@ def plot_explained_variance(ica_data, pc=True, ax=None):
         :class:`~matplotlib.axes.Axes` containing the line plot
     """
 
+    if not ax:
+        fig, ax = plt.subplots()
+
     # Get IC explained variance
     ic_var = []
     for imodulon in ica_data.imodulon_names:
         ic_var.append(explained_variance(ica_data, imodulons=imodulon))
     ic_var = np.insert(np.cumsum(sorted(ic_var, reverse=True)), 0, 0)
 
-    if not ax:
-        fig, ax = plt.subplots()
-
     ax.plot(range(len(ic_var)), ic_var, label="Independent Components")
 
     if pc:
@@ -1445,6 +1394,175 @@ def plot_explained_variance(ica_data, pc=True, ax=None):
     return ax
 
 
+def compare_imodulons_vs_regulons(
+    ica_data,
+    imodulons=None,
+    cat_column=None,
+    size_column=None,
+    scale=1,
+    reg_only=True,
+    xlabel=None,
+    ylabel=None,
+    vline=0.6,
+    hline=0.6,
+    ax=None,
+    scatter_kwargs=None,
+    ax_font_kwargs=None,
+    legend_kwargs=None,
+):
+    """
+    Compare the overlaps between iModulons and their linked regulons
+
+    Parameters
+    ----------
+    ica_data: ~pymodulon.core.IcaData
+        :class:`~pymodulon.core.IcaData` object
+    imodulons: list, optional
+        List of iModulons to plot
+    cat_column: str, optional
+        Column in the `imodulon_table` that stores the category of each iModulon
+    size_column: str, optional
+        Column in the `imodulon_table` that stores the size of each iModulon
+    scale: float, optional (default: 1)
+        Value used to scale the size of each point
+    reg_only: bool (default: True)
+        Only plot iModulons with an entry in the `regulator` column of the
+        `imodulon_table`
+    xlabel: str, optional
+        Custom x-axis label (default: "# shared genes/Regulon size")
+    ylabel: str, optional
+        Custom y-axis label (default: "# shared genes/iModulon size")
+    vline: float, optional (default: 0.6)
+        Draw a dashed vertical line
+    hline: float, optional (default: 0.6)
+        Draw a dashed horizontal line
+    ax: ~matplotlib.axes.Axes, optional
+        Axes object to plot on, otherwise use current Axes
+    scatter_kwargs: dict, optional
+        Additional keyword arguments passed to :func:`matplotlib.pyplot.scatter`
+    ax_font_kwargs: dict, optional
+        Additional keyword arguments for axes labels
+    legend_kwargs: dict, optional
+        Additional keyword arguments passed to :func:`matplotlib.pyplot.legend`
+
+    Returns
+    -------
+    ax: ~matplotlib.axes.Axes
+        :class:`~matplotlib.axes.Axes` containing the line plot
+    """
+
+    # Set up axis
+    if not ax:
+        fig, ax = plt.subplots(figsize=(5, 5))
+
+    # Handle kwargs
+    if scatter_kwargs is None:
+        scatter_kwargs = {}
+    if ax_font_kwargs is None:
+        ax_font_kwargs = {}
+    if legend_kwargs is None:
+        legend_kwargs = {}
+
+    # Set axes labels
+    if xlabel is None:
+        xlabel = "$\\frac{\\mathrm{\\#\\;Shared\\;Genes}}{\\mathrm{Regulon\\;Size}}$"
+        xlabelscale = 2
+    else:
+        xlabelscale = 1
+
+    if ylabel is None:
+        ylabel = "$\\frac{\\mathrm{\\#\\;Shared\\;Genes}}{\\mathrm{iModulon\\;Size}}$"
+        ylabelscale = 2
+    else:
+        ylabelscale = 1
+
+    # Select iModulons
+    if imodulons is None:
+        reg_table = ica_data.imodulon_table.copy()
+        if reg_only:
+            reg_table = reg_table[reg_table.regulator.notnull()]
+    else:
+        reg_table = ica_data.imodulon_table.loc[imodulons]
+
+    # Select category column
+    if cat_column is None:
+        reg_table["_category"] = "iModulons"
+        cat_column = "_category"
+
+    # Make sure all necessary columns exist
+    if reg_table.recall.isnull().any():
+        logging.warning(
+            "Some iModulons have missing `recall` entries in the "
+            "`imodulon_table` "
+            "and will not be shown"
+        )
+    if reg_table.precision.isnull().any():
+        logging.warning(
+            "Some iModulons have missing `precision` entries in the "
+            "`imodulon_table` and will not be shown"
+        )
+    if size_column is not None and reg_table[size_column].isnull().any():
+        logging.warning(
+            "Some iModulons have missing {} entries in the "
+            "`imodulon_table`".format(size_column)
+        )
+
+    for cat, group in reg_table.groupby(cat_column):
+
+        # Set point sizes
+        if size_column is None:
+            size_ivr = scatter_kwargs.pop("s", plt.rcParams["lines.markersize"])
+        else:
+            size_ivr = scatter_kwargs.pop("s", group[size_column])
+
+        edgecolor_ivr = scatter_kwargs.pop("edgecolor", "k")
+
+        ax.scatter(
+            group.recall,
+            group.precision,
+            s=size_ivr * scale,
+            edgecolor=edgecolor_ivr,
+            label=cat,
+            **scatter_kwargs,
+        )
+
+    # Set plot boundaries
+    xmin, xmax = ax.get_xlim()
+    xmin = min(xmin, 0)
+    xmax = max(xmax, 1)
+    ax.set_xlim((xmin, xmax))
+
+    ymin, ymax = ax.get_ylim()
+    ymin = min(ymin, 0)
+    ymax = max(ymax, 1)
+    ax.set_ylim((ymin, ymax))
+
+    # Add dashed lines
+    if hline:
+        ax.hlines(hline, xmin, xmax, linestyles="dashed", colors="gray", zorder=0)
+    if vline:
+        ax.vlines(vline, xmin, xmax, linestyles="dashed", colors="gray", zorder=0)
+
+    # Set axis labels
+    label_size = ax_font_kwargs.pop("fontsize", plt.rcParams["font.size"])
+    xlabel_size = label_size * xlabelscale
+    ax.set_xlabel(xlabel, fontsize=xlabel_size, **ax_font_kwargs)
+
+    ylabel_size = label_size * ylabelscale
+    ax.set_ylabel(ylabel, fontsize=ylabel_size, **ax_font_kwargs)
+
+    # Set legend
+    bbox_to_anchor_ivr = legend_kwargs.pop("bbox_to_anchor", (1, 1))
+    ax.legend(bbox_to_anchor=bbox_to_anchor_ivr, **legend_kwargs)
+
+    return ax
+
+
+######################
+# Cluster Activities #
+######################
+
+
 def cluster_activities(
     ica_data,
     correlation_method="spearman",
@@ -1463,7 +1581,7 @@ def cluster_activities(
     dimca_label=True,
     dimca_adjust=True,
     dimca_table=False,
-    **dimca_kwargs,
+    **dima_kwargs,
 ):
     """
     Cluster all iModulon activity profiles using hierarchical clustering and display
@@ -1511,7 +1629,7 @@ def cluster_activities(
         Auto-adjust DiMCA cluster labels (default: True)
     dimca_table: bool
         Return DiMCA table (default: False)
-    **dimca_kwargs: dict, optional
+    **dima_kwargs: dict, optional
         Additional keyword arguments passed to :func:`pymodulon.plotting.dima`
 
     Returns
@@ -1844,7 +1962,7 @@ def cluster_activities(
         cluster_A_df = cluster_A_df.append(ica_data.A.loc[list(singleton_ims)])
 
         # add to kwargs
-        dimca_kwargs["alternate_A"] = cluster_A_df
+        dima_kwargs["alternate_A"] = cluster_A_df
 
         # now we can pretty much proceed as normal with DIMCA; just have a
         # different activity matrix, but the procedure is the same from here
@@ -1857,7 +1975,7 @@ def cluster_activities(
             label=dimca_label,
             adjust=dimca_adjust,
             table=dimca_table,
-            **dimca_kwargs,
+            **dima_kwargs,
         )
         if dimca_table:
             returns += dimca_return
@@ -1875,11 +1993,17 @@ def cluster_activities(
 def metadata_boxplot(
     ica_data,
     imodulon,
+    show_points=True,
     n_boxes=3,
+    samples=None,
     strip_conc=True,
     ignore_cols=None,
     use_cols=None,
     return_results=False,
+    ax=None,
+    box_kwargs=None,
+    strip_kwargs=None,
+    swarm_kwargs=None,
 ):
     """
     Uses a decision tree regressor to automatically cluster iModulon activities
@@ -1889,10 +2013,16 @@ def metadata_boxplot(
     ----------
     ica_data: ~pymodulon.core.IcaData
         :class:`~pymodulon.core.IcaData` object
-    imodulon : int or str
+    imodulon: int or str
         `iModulon` name
+    show_points: bool or str (default: True)
+        Overlay individual points on top of the boxplot. By default, this uses
+        :func:`seaborn.stripplot`. `show_points='swarm'` will use
+        :func`seaborn.swarmplot`.
     n_boxes: int
         Number of boxes to create
+    samples: list, optional
+        Subset of samples to analyze
     strip_conc: bool
         Remove concentrations from metadata (e.g. "glucose(2g/L)" would be
         interpreted as just "glucose")
@@ -1903,6 +2033,14 @@ def metadata_boxplot(
         List of columns to use. This supercedes ignore_cols.
     return_results: bool
         Return a dataframe describing the classifications
+    ax: ~matplotlib.axes.Axes, optional
+        Axes object to plot on, otherwise use current Axes
+    box_kwargs: dict, optional
+        Additional keyword arguments passed to :func:`seaborn.boxplot`
+    strip_kwargs: dict, optional
+        Additional keyword arguments passed to :func:`seaborn.stripplot`
+    swarm_kwargs: dict, optional
+        Additional keyword arguments passed to :func:`seaborn.swarmplot`
 
     Returns
     -------
@@ -1911,10 +2049,33 @@ def metadata_boxplot(
     df_classes: ~pd.DataFrame
         Metadata classifications of the samples
     """
-    activities = ica_data.A.loc[imodulon]
+
+    if not ax:
+        fig, ax = plt.subplots()
+
+    if show_points is True:
+        show_points = "strip"
+
+    if box_kwargs is None:
+        box_kwargs = {}
+
+    if strip_kwargs is None:
+        strip_kwargs = {}
+
+    if swarm_kwargs is None:
+        swarm_kwargs = {}
+
+    if samples is None:
+        samples = ica_data.sample_names
+
+    activities = ica_data.A.loc[imodulon, samples]
 
     encoding, features = _encode_metadata(
-        ica_data, ignore_cols=ignore_cols, use_cols=use_cols, strip_conc=strip_conc
+        ica_data,
+        samples=samples,
+        ignore_cols=ignore_cols,
+        use_cols=use_cols,
+        strip_conc=strip_conc,
     )
 
     clf = _train_classifier(activities, features, max_leaf_nodes=n_boxes)
@@ -1923,18 +2084,44 @@ def metadata_boxplot(
 
     df_classes = df_classes.sort_values(imodulon, ascending=False)
 
-    fig, ax = plt.subplots()
-    sns.boxplot(data=df_classes, x=imodulon, y="category")
+    # If using either a stripplot or swarmplot, hide fliers
+    if show_points in ["strip", "swarm"]:
+        box_kwargs.update({"fliersize": 0})
+
+    sns.boxplot(data=df_classes, x=imodulon, y="category", **box_kwargs)
+
+    if show_points == "strip":
+        color_mdbp = strip_kwargs.pop("color", "k")
+        jitter_mdbp = strip_kwargs.pop("color", 0.3)
+
+        sns.stripplot(
+            data=df_classes,
+            x=imodulon,
+            y="category",
+            color=color_mdbp,
+            jitter=jitter_mdbp,
+            **strip_kwargs,
+        )
+
+    elif show_points == "swarm":
+        color_mdbp = swarm_kwargs.pop("color", "k")
+        sns.swarmplot(
+            data=df_classes, x=imodulon, y="category", color=color_mdbp, **swarm_kwargs
+        )
+
     ax.set_ylabel("")
+
     if return_results:
         return ax, df_classes
     else:
         return ax
 
 
-def _encode_metadata(ica_data, use_cols=None, ignore_cols=None, strip_conc=True):
+def _encode_metadata(
+    ica_data, samples, use_cols=None, ignore_cols=None, strip_conc=True
+):
     # Convert values to strings
-    metadata = ica_data.sample_table.copy()
+    metadata = ica_data.sample_table.loc[samples].copy()
     metadata = metadata.astype(str).fillna("")
 
     # Select columns
@@ -2092,7 +2279,7 @@ def _get_fit(x, y):
                 all_params.append(
                     curve_fit(_broken_line, x, y, p0=[1, 1, c], maxfev=5000)[0]
                 )
-            except OptimizeWarning:
+            except (OptimizeWarning, RuntimeError):
                 pass
 
     best_r2 = -np.inf
@@ -2115,7 +2302,7 @@ def _get_fit(x, y):
 
 
 def _broken_line(x, A, B, C):
-    y = np.zeros(len(x), dtype=np.float)
+    y = np.zeros(len(x), dtype=float)
     y += (A * x + B) * (x >= C)
     y += (A * C + B) * (x < C)
     return y
@@ -2182,19 +2369,6 @@ def _mod_freedman_diaconis(ica_data, imodulon):
     return np.arange(xmin, xmax + width, width)
 
 
-def _save_figures(fig, savefig_kwargs):
-    """Check for savefig_kwargs, then save current figure instance"""
-
-    # Check for savefig_kwargs
-    if savefig_kwargs:
-        savefig_kwargs["fname"] = savefig_kwargs.get("fname", "./plot.svg")
-    else:
-        savefig_kwargs = {"fname": "./plot.svg"}
-
-    # Plot current figure instance using savefig_kwargs
-    fig.savefig(**savefig_kwargs)
-
-
 ##########################
 # Experimental Functions #
 ##########################
